## Summary

- What does this PR change? Why?

## Type

- [ ] feat
- [ ] fix
- [ ] docs
- [ ] refactor
- [ ] perf
- [ ] ci/chore

## Checklist

- [ ] PR title follows Conventional Commits (e.g., feat: add X)
- [ ] Tests added/updated when necessary
- [ ] Docs updated (README/docs/CHANGELOG as needed)
- [ ] CI green

## Breaking changes

- [ ] No breaking changes
- [ ] Breaking changes (describe):

## Additional context

- Screenshots, notes, links

